.. _home:

=================
Welcome to sktime
=================

  A unified framework for machine learning with time series

Mission
=======

.. include:: about/_mission.rst


Scope
=====

sktime features a unified interface for multiple time series learning tasks.
Currently, we support :ref:`forecasting <forecasting_ref>`, :ref:`time series classification <classification_ref>` and :ref:`time series regression <regression_ref>`.
We have experimental support for time series clustering and time series annotation.

Features:

* API for machine learning with time series, for the purpose of specifying, fitting, applying and validating machine learning models
* Interactive user experience with scikit-learn like syntax conventions

Technical specification:

* In-memory computation of a single machine, no distributed computing
* Medium-sized data in pandas and NumPy
* Modular, principled and object-oriented API
* Making use of interactive Python interpreter, no command-line interface or graphical user interface

Contents
========

.. toctree::
   :maxdepth: 1
   :hidden:

   get_started
   users
   api_reference
   get_involved
   developers
   about

.. panels::
    :card: + intro-card text-center

    ---

    Get Started
    ^^^^^^^^^^^

    Get started using ``sktime`` quickly.

    +++

    .. link-button:: get_started
            :type: ref
            :text: Get Started
            :classes: btn-block btn-secondary stretched-link

    ---

    Users
    ^^^^^

    Find user documentation.

    +++

    .. link-button:: users
            :type: ref
            :text: Users
            :classes: btn-block btn-secondary stretched-link

    ---

    API Reference
    ^^^^^^^^^^^^^

    Understand sktime's API.

    +++

    .. link-button:: api_reference
            :type: ref
            :text: API Reference
            :classes: btn-block btn-secondary stretched-link

    ---

    Get Involved
    ^^^^^^^^^^^^

    Find out how you can contribute.

    +++

    .. link-button:: get_involved
            :type: ref
            :text: Get Involved
            :classes: btn-block btn-secondary stretched-link

    ---

    Developers
    ^^^^^^^^^^

    Information for developers.

    +++

    .. link-button:: developers
            :type: ref
            :text: Developers
            :classes: btn-block btn-secondary stretched-link

    ---

    About
    ^^^^^

    Learn more about ``sktime``.

    +++

    .. link-button:: about
            :type: ref
            :text: Learn More
            :classes: btn-block btn-secondary stretched-link
